translate.lang.code_or

Package translate :: Package lang :: Module code_or |
[hide private]
[frames] | no frames]

# Source Code for Module translate.lang.code_or

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2007 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # translate is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # translate is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with translate; if not, write to the Free Software
    20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    21
    22  """This module represents Oriya language.
    23
    24  For more information, see U{http://en.wikipedia.org/wiki/Oriya_language}
    25  """
    26
    27  import re
    28
    29  from translate.lang import common
    30
    31 -class code_or(common.Common):
    32      """This class represents Oriya."""
    33
    34      sentenceend = u"।!?…"
    35
    36      sentencere = re.compile(r"""(?s)    #make . also match newlines
    37                              .*?         #anything, but match non-greedy
    38                              [%s]        #the puntuation for sentence ending
    39                              \s+         #the spacing after the puntuation
    40                              (?=[^a-z\d])#lookahead that next part starts with caps
    41                              """ % sentenceend, re.VERBOSE)
    42
    43      puncdict = {
    44          u". ": u"। ",
    45          u".\n": u"।\n",
    46      }
    47
    48      ignoretests = ["startcaps", "simplecaps"]
    49